# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v1.1.0] - 2022/02/16

### Added

- Use own HTTP client, if special settings are needed

## [v1.0.2] - 2022/12/09

### Fixed

- The API does not provide the sourceTime data in every case

## [v1.0.1] - 2021/03/23

### Fixed

- Docs build

## [v1.0.0] - 2021/03/23

### Added

- Autogenerated docs using Sphinx

## [v0.3.0] - 2021/02/08

### Added

- Query used API version with ssllabs.api.API_VERSION
- Low level methods now can reuse an existing AsyncClient instance

### Fixed

- Fix dataclasses for certain situations

## [v0.2.0] - 2021/01/28

### Added

- High level methods now respect cool off and maximum assessment rate limits

## [v0.1.1] - 2021/01/27

### Fixed

- Fixed pip installation

## [v0.1.0] - 2021/01/27

### Added

- High level usage methods
- Low level info API
- Low level analyze API
- Low level getEndpointData API
- Low level getStatusCodes API
- Low level getRootCertsRaw API
